aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/Text/Pandoc/Readers/Textile.hs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/Text/Pandoc/Readers/Textile.hs b/src/Text/Pandoc/Readers/Textile.hs
index 3465eebbe..f64c9e416 100644
--- a/src/Text/Pandoc/Readers/Textile.hs
+++ b/src/Text/Pandoc/Readers/Textile.hs
@@ -91,8 +91,8 @@ specialChars = "\\[]<>*#_@~-+^&,.;:!?|\"'%"
-- | Generate a Pandoc ADT from a textile document
parseTextile :: GenParser Char ParserState Pandoc
parseTextile = do
- -- textile allows raw HTML
- updateState (\state -> state { stateParseRaw = True })
+ -- textile allows raw HTML and does smart punctuation by default
+ updateState (\state -> state { stateParseRaw = True, stateSmart = True })
many blankline
blocks <- parseBlocks
return $ Pandoc (Meta [Str ""] [[Str ""]] [Str ""]) blocks -- FIXME